/* 
 * AT-RTS
 *
 * # AT-RTS (Remote Translation Service) API Documentation Welcome to the AT-RTS API documentation. AT-RTS is a robust web API designed to integrate our advanced translation systems into client systems, enabling full control over the content translation process. ## API Overview AT-RTS, built on a SOAP web service framework, offers REST interoperability starting from version 5.3.0, facilitating seamless integration into diverse environments. ### Key Functionalities   1. **Operating Check**      Verifies the active status of the service.   2. **Synchronous Translation**      Handles requests for immediate, automated (non-human) translation.   3. **Asynchronous Translation**      Processes orders for specialized professional translations on a deferred basis. Each request generates a unique token to identify and track the translation order. This token is essential for subsequent retrieval and proofreading of the translations.   ### Special Features   - **Callback URL**: Asynchronous translation requests can specify a callback URL to activate a notification service once the translation is complete. This allows clients to automate the download process of completed translations.   - **Translation Return Request**: Using the token from an asynchronous request, clients can retrieve the completed translation. If the translation is not yet complete, the system provides current status information.   - **Cancellation Request**: Allows clients to cancel previously submitted asynchronous translation requests using the token, provided the translation process has not yet commenced.   - **List of Requests**: Offers a comprehensive list detailing the status and usage of translation orders. Each entry includes:   - `projectid`: Unique identifier for the AT project.   - `token`: Token associated with the request.   - `sourcelang`: Source language of the text.   - `targetlang`: Target language for the translation.   - `filename`: File name associated with the request.   - `wordcount`: Total word count of the document.   - `status`: Current status of the translation (with codes such as 10: Under Review, 20: Ready, 30: Delivered, etc.).   - `urlcallback`: Optional URL for receiving completed translations.   - `errnotifiersendto`: Optional email address for receiving notifications on translation errors.   - `dateinsert`: Registration date of the translation request.   - `type`: Specifies whether the translation is SYNCHRONOUS or ASYNCHRONOUS.   ### Reliability Guarantees   ATLS Global ensures reliable return of asynchronous translations to client infrastructures. In the event of communication failures, the system is designed to alert clients through a warning email to the specified contact address, enhancing overall service reliability.   For detailed API usage examples and further technical information, refer to the subsequent sections of this documentation.
 *
 * OpenAPI spec version: 5.6.0
 * Contact: tec@at-ls.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using ATLS.Api.Client;
using ATLS.Api.Model;

namespace ATLS.Api.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public interface IRestapiApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// delFileByToken
        /// </summary>
        /// <remarks>
        /// Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>OutFile</returns>
        OutFile DelFileByToken (Object body);

        /// <summary>
        /// delFileByToken
        /// </summary>
        /// <remarks>
        /// Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>ApiResponse of OutFile</returns>
        ApiResponse<OutFile> DelFileByTokenWithHttpInfo (Object body);
        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>OutFile</returns>
        OutFile GetFileByToken (Object body);

        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>ApiResponse of OutFile</returns>
        ApiResponse<OutFile> GetFileByTokenWithHttpInfo (Object body);
        /// <summary>
        /// getList
        /// </summary>
        /// <remarks>
        /// Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>OutList</returns>
        OutList GetList (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null);

        /// <summary>
        /// getList
        /// </summary>
        /// <remarks>
        /// Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>ApiResponse of OutList</returns>
        ApiResponse<OutList> GetListWithHttpInfo (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null);
        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>OutFile</returns>
        OutFile GetgetFileByToken (int? projectid, string token, string options = null);

        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>ApiResponse of OutFile</returns>
        ApiResponse<OutFile> GetgetFileByTokenWithHttpInfo (int? projectid, string token, string options = null);
        /// <summary>
        /// ping
        /// </summary>
        /// <remarks>
        /// Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>InlineResponse200</returns>
        InlineResponse200 Ping ();

        /// <summary>
        /// ping
        /// </summary>
        /// <remarks>
        /// Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of InlineResponse200</returns>
        ApiResponse<InlineResponse200> PingWithHttpInfo ();
        /// <summary>
        /// translateAsynchronous
        /// </summary>
        /// <remarks>
        /// An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>OutToken</returns>
        OutToken TranslateAsynchronous (Object body);

        /// <summary>
        /// translateAsynchronous
        /// </summary>
        /// <remarks>
        /// An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>ApiResponse of OutToken</returns>
        ApiResponse<OutToken> TranslateAsynchronousWithHttpInfo (Object body);
        /// <summary>
        /// translateSynchronous
        /// </summary>
        /// <remarks>
        /// Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>OutFile</returns>
        OutFile TranslateSynchronous (Object body);

        /// <summary>
        /// translateSynchronous
        /// </summary>
        /// <remarks>
        /// Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>ApiResponse of OutFile</returns>
        ApiResponse<OutFile> TranslateSynchronousWithHttpInfo (Object body);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// delFileByToken
        /// </summary>
        /// <remarks>
        /// Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>Task of OutFile</returns>
        System.Threading.Tasks.Task<OutFile> DelFileByTokenAsync (Object body);

        /// <summary>
        /// delFileByToken
        /// </summary>
        /// <remarks>
        /// Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        System.Threading.Tasks.Task<ApiResponse<OutFile>> DelFileByTokenAsyncWithHttpInfo (Object body);
        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>Task of OutFile</returns>
        System.Threading.Tasks.Task<OutFile> GetFileByTokenAsync (Object body);

        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        System.Threading.Tasks.Task<ApiResponse<OutFile>> GetFileByTokenAsyncWithHttpInfo (Object body);
        /// <summary>
        /// getList
        /// </summary>
        /// <remarks>
        /// Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of OutList</returns>
        System.Threading.Tasks.Task<OutList> GetListAsync (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null);

        /// <summary>
        /// getList
        /// </summary>
        /// <remarks>
        /// Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of ApiResponse (OutList)</returns>
        System.Threading.Tasks.Task<ApiResponse<OutList>> GetListAsyncWithHttpInfo (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null);
        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of OutFile</returns>
        System.Threading.Tasks.Task<OutFile> GetgetFileByTokenAsync (int? projectid, string token, string options = null);

        /// <summary>
        /// getFileByToken
        /// </summary>
        /// <remarks>
        /// Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        System.Threading.Tasks.Task<ApiResponse<OutFile>> GetgetFileByTokenAsyncWithHttpInfo (int? projectid, string token, string options = null);
        /// <summary>
        /// ping
        /// </summary>
        /// <remarks>
        /// Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of InlineResponse200</returns>
        System.Threading.Tasks.Task<InlineResponse200> PingAsync ();

        /// <summary>
        /// ping
        /// </summary>
        /// <remarks>
        /// Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (InlineResponse200)</returns>
        System.Threading.Tasks.Task<ApiResponse<InlineResponse200>> PingAsyncWithHttpInfo ();
        /// <summary>
        /// translateAsynchronous
        /// </summary>
        /// <remarks>
        /// An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>Task of OutToken</returns>
        System.Threading.Tasks.Task<OutToken> TranslateAsynchronousAsync (Object body);

        /// <summary>
        /// translateAsynchronous
        /// </summary>
        /// <remarks>
        /// An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>Task of ApiResponse (OutToken)</returns>
        System.Threading.Tasks.Task<ApiResponse<OutToken>> TranslateAsynchronousAsyncWithHttpInfo (Object body);
        /// <summary>
        /// translateSynchronous
        /// </summary>
        /// <remarks>
        /// Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>Task of OutFile</returns>
        System.Threading.Tasks.Task<OutFile> TranslateSynchronousAsync (Object body);

        /// <summary>
        /// translateSynchronous
        /// </summary>
        /// <remarks>
        /// Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </remarks>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        System.Threading.Tasks.Task<ApiResponse<OutFile>> TranslateSynchronousAsyncWithHttpInfo (Object body);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public partial class RestapiApi : IRestapiApi
    {
        private ATLS.Api.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="RestapiApi"/> class.
        /// </summary>
        /// <returns></returns>
        public RestapiApi(String basePath)
        {
            this.Configuration = new ATLS.Api.Client.Configuration { BasePath = basePath };

            ExceptionFactory = ATLS.Api.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="RestapiApi"/> class
        /// </summary>
        /// <returns></returns>
        public RestapiApi()
        {
            this.Configuration = ATLS.Api.Client.Configuration.Default;

            ExceptionFactory = ATLS.Api.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="RestapiApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public RestapiApi(ATLS.Api.Client.Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = ATLS.Api.Client.Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = ATLS.Api.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public ATLS.Api.Client.Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public ATLS.Api.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public IDictionary<String, String> DefaultHeader()
        {
            return new ReadOnlyDictionary<string, string>(this.Configuration.DefaultHeader);
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// delFileByToken Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>OutFile</returns>
        public OutFile DelFileByToken (Object body)
        {
             ApiResponse<OutFile> localVarResponse = DelFileByTokenWithHttpInfo(body);
             return localVarResponse.Data;
        }

        /// <summary>
        /// delFileByToken Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>ApiResponse of OutFile</returns>
        public ApiResponse< OutFile > DelFileByTokenWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->DelFileByToken");

            var localVarPath = "/delFileByToken";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DelFileByToken", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

        /// <summary>
        /// delFileByToken Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>Task of OutFile</returns>
        public async System.Threading.Tasks.Task<OutFile> DelFileByTokenAsync (Object body)
        {
             ApiResponse<OutFile> localVarResponse = await DelFileByTokenAsyncWithHttpInfo(body);
             return localVarResponse.Data;

        }

        /// <summary>
        /// delFileByToken Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the **status** of the translation. Possible values for asynchronous translations are: - 10: Under review - 20: Ready and to be delivered - 30: Delivered - 40: Deleted - 50: Delivery expired - 90: Document entry error - 100: Processing error  The **filename** key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Document information to be deleted</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<OutFile>> DelFileByTokenAsyncWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->DelFileByToken");

            var localVarPath = "/delFileByToken";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DelFileByToken", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>OutFile</returns>
        public OutFile GetFileByToken (Object body)
        {
             ApiResponse<OutFile> localVarResponse = GetFileByTokenWithHttpInfo(body);
             return localVarResponse.Data;
        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>ApiResponse of OutFile</returns>
        public ApiResponse< OutFile > GetFileByTokenWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->GetFileByToken");

            var localVarPath = "/getFileByToken";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFileByToken", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>Task of OutFile</returns>
        public async System.Threading.Tasks.Task<OutFile> GetFileByTokenAsync (Object body)
        {
             ApiResponse<OutFile> localVarResponse = await GetFileByTokenAsyncWithHttpInfo(body);
             return localVarResponse.Data;

        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The **filename** key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised file request</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<OutFile>> GetFileByTokenAsyncWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->GetFileByToken");

            var localVarPath = "/getFileByToken";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFileByToken", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

        /// <summary>
        /// getList Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>OutList</returns>
        public OutList GetList (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null)
        {
             ApiResponse<OutList> localVarResponse = GetListWithHttpInfo(projectid, sourcelang, targetlang, datecutoff, options);
             return localVarResponse.Data;
        }

        /// <summary>
        /// getList Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>ApiResponse of OutList</returns>
        public ApiResponse< OutList > GetListWithHttpInfo (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null)
        {
            // verify the required parameter 'projectid' is set
            if (projectid == null)
                throw new ApiException(400, "Missing required parameter 'projectid' when calling RestapiApi->GetList");
            // verify the required parameter 'sourcelang' is set
            if (sourcelang == null)
                throw new ApiException(400, "Missing required parameter 'sourcelang' when calling RestapiApi->GetList");
            // verify the required parameter 'targetlang' is set
            if (targetlang == null)
                throw new ApiException(400, "Missing required parameter 'targetlang' when calling RestapiApi->GetList");
            // verify the required parameter 'datecutoff' is set
            if (datecutoff == null)
                throw new ApiException(400, "Missing required parameter 'datecutoff' when calling RestapiApi->GetList");

            var localVarPath = "/getList";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (projectid != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "projectid", projectid)); // query parameter
            if (sourcelang != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "sourcelang", sourcelang)); // query parameter
            if (targetlang != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "targetlang", targetlang)); // query parameter
            if (datecutoff != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "datecutoff", datecutoff)); // query parameter
            if (options != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "options", options)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutList>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutList) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutList)));
        }

        /// <summary>
        /// getList Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of OutList</returns>
        public async System.Threading.Tasks.Task<OutList> GetListAsync (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null)
        {
             ApiResponse<OutList> localVarResponse = await GetListAsyncWithHttpInfo(projectid, sourcelang, targetlang, datecutoff, options);
             return localVarResponse.Data;

        }

        /// <summary>
        /// getList Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="sourcelang">Source language code in ISO-639-3 format.</param>
        /// <param name="targetlang">Target language code in ISO-639-3 format.</param>
        /// <param name="datecutoff">Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of ApiResponse (OutList)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<OutList>> GetListAsyncWithHttpInfo (int? projectid, string sourcelang, string targetlang, string datecutoff, string options = null)
        {
            // verify the required parameter 'projectid' is set
            if (projectid == null)
                throw new ApiException(400, "Missing required parameter 'projectid' when calling RestapiApi->GetList");
            // verify the required parameter 'sourcelang' is set
            if (sourcelang == null)
                throw new ApiException(400, "Missing required parameter 'sourcelang' when calling RestapiApi->GetList");
            // verify the required parameter 'targetlang' is set
            if (targetlang == null)
                throw new ApiException(400, "Missing required parameter 'targetlang' when calling RestapiApi->GetList");
            // verify the required parameter 'datecutoff' is set
            if (datecutoff == null)
                throw new ApiException(400, "Missing required parameter 'datecutoff' when calling RestapiApi->GetList");

            var localVarPath = "/getList";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (projectid != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "projectid", projectid)); // query parameter
            if (sourcelang != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "sourcelang", sourcelang)); // query parameter
            if (targetlang != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "targetlang", targetlang)); // query parameter
            if (datecutoff != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "datecutoff", datecutoff)); // query parameter
            if (options != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "options", options)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutList>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutList) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutList)));
        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>OutFile</returns>
        public OutFile GetgetFileByToken (int? projectid, string token, string options = null)
        {
             ApiResponse<OutFile> localVarResponse = GetgetFileByTokenWithHttpInfo(projectid, token, options);
             return localVarResponse.Data;
        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>ApiResponse of OutFile</returns>
        public ApiResponse< OutFile > GetgetFileByTokenWithHttpInfo (int? projectid, string token, string options = null)
        {
            // verify the required parameter 'projectid' is set
            if (projectid == null)
                throw new ApiException(400, "Missing required parameter 'projectid' when calling RestapiApi->GetgetFileByToken");
            // verify the required parameter 'token' is set
            if (token == null)
                throw new ApiException(400, "Missing required parameter 'token' when calling RestapiApi->GetgetFileByToken");

            var localVarPath = "/getFileByToken";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (projectid != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "projectid", projectid)); // query parameter
            if (token != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "token", token)); // query parameter
            if (options != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "options", options)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetgetFileByToken", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of OutFile</returns>
        public async System.Threading.Tasks.Task<OutFile> GetgetFileByTokenAsync (int? projectid, string token, string options = null)
        {
             ApiResponse<OutFile> localVarResponse = await GetgetFileByTokenAsyncWithHttpInfo(projectid, token, options);
             return localVarResponse.Data;

        }

        /// <summary>
        /// getFileByToken Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are: - 10: Under review - 20: Ready and pending delivery - 30: Delivered - 40: Deleted - 50: Expired delivery - 90: Documental entry error - 100: Processing error  The &lt;b&gt;filename&lt;/b&gt; key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="projectid">Translation project identifier.</param>
        /// <param name="token">Token resulting from the asynchronous translation request.</param>
        /// <param name="options">JSON auxiliary options. (optional)</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<OutFile>> GetgetFileByTokenAsyncWithHttpInfo (int? projectid, string token, string options = null)
        {
            // verify the required parameter 'projectid' is set
            if (projectid == null)
                throw new ApiException(400, "Missing required parameter 'projectid' when calling RestapiApi->GetgetFileByToken");
            // verify the required parameter 'token' is set
            if (token == null)
                throw new ApiException(400, "Missing required parameter 'token' when calling RestapiApi->GetgetFileByToken");

            var localVarPath = "/getFileByToken";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (projectid != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "projectid", projectid)); // query parameter
            if (token != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "token", token)); // query parameter
            if (options != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "options", options)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetgetFileByToken", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

        /// <summary>
        /// ping Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>InlineResponse200</returns>
        public InlineResponse200 Ping ()
        {
             ApiResponse<InlineResponse200> localVarResponse = PingWithHttpInfo();
             return localVarResponse.Data;
        }

        /// <summary>
        /// ping Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of InlineResponse200</returns>
        public ApiResponse< InlineResponse200 > PingWithHttpInfo ()
        {

            var localVarPath = "/ping";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("Ping", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<InlineResponse200>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (InlineResponse200) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(InlineResponse200)));
        }

        /// <summary>
        /// ping Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of InlineResponse200</returns>
        public async System.Threading.Tasks.Task<InlineResponse200> PingAsync ()
        {
             ApiResponse<InlineResponse200> localVarResponse = await PingAsyncWithHttpInfo();
             return localVarResponse.Data;

        }

        /// <summary>
        /// ping Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (InlineResponse200)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<InlineResponse200>> PingAsyncWithHttpInfo ()
        {

            var localVarPath = "/ping";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("Ping", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<InlineResponse200>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (InlineResponse200) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(InlineResponse200)));
        }

        /// <summary>
        /// translateAsynchronous An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>OutToken</returns>
        public OutToken TranslateAsynchronous (Object body)
        {
             ApiResponse<OutToken> localVarResponse = TranslateAsynchronousWithHttpInfo(body);
             return localVarResponse.Data;
        }

        /// <summary>
        /// translateAsynchronous An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>ApiResponse of OutToken</returns>
        public ApiResponse< OutToken > TranslateAsynchronousWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->TranslateAsynchronous");

            var localVarPath = "/translateAsynchronous";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("TranslateAsynchronous", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutToken>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutToken) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutToken)));
        }

        /// <summary>
        /// translateAsynchronous An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>Task of OutToken</returns>
        public async System.Threading.Tasks.Task<OutToken> TranslateAsynchronousAsync (Object body)
        {
             ApiResponse<OutToken> localVarResponse = await TranslateAsynchronousAsyncWithHttpInfo(body);
             return localVarResponse.Data;

        }

        /// <summary>
        /// translateAsynchronous An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of a revised translation</param>
        /// <returns>Task of ApiResponse (OutToken)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<OutToken>> TranslateAsynchronousAsyncWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->TranslateAsynchronous");

            var localVarPath = "/translateAsynchronous";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("TranslateAsynchronous", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutToken>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutToken) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutToken)));
        }

        /// <summary>
        /// translateSynchronous Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>OutFile</returns>
        public OutFile TranslateSynchronous (Object body)
        {
             ApiResponse<OutFile> localVarResponse = TranslateSynchronousWithHttpInfo(body);
             return localVarResponse.Data;
        }

        /// <summary>
        /// translateSynchronous Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>ApiResponse of OutFile</returns>
        public ApiResponse< OutFile > TranslateSynchronousWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->TranslateSynchronous");

            var localVarPath = "/translateSynchronous";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("TranslateSynchronous", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

        /// <summary>
        /// translateSynchronous Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>Task of OutFile</returns>
        public async System.Threading.Tasks.Task<OutFile> TranslateSynchronousAsync (Object body)
        {
             ApiResponse<OutFile> localVarResponse = await TranslateSynchronousAsyncWithHttpInfo(body);
             return localVarResponse.Data;

        }

        /// <summary>
        /// translateSynchronous Synchronous (non-human automatic translation) translation order request. After the request, the service returns the file translated into the specified target language. 
        /// </summary>
        /// <exception cref="ATLS.Api.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">Example of synchronous machine translation</param>
        /// <returns>Task of ApiResponse (OutFile)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<OutFile>> TranslateSynchronousAsyncWithHttpInfo (Object body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling RestapiApi->TranslateSynchronous");

            var localVarPath = "/translateSynchronous";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key")))
            {
                localVarHeaderParams["X-ATRTS-API-Key"] = this.Configuration.GetApiKeyWithPrefix("X-ATRTS-API-Key");
            }
            // authentication (BasicAuth) required
            // http basic authentication required
            if (!String.IsNullOrEmpty(this.Configuration.Username) || !String.IsNullOrEmpty(this.Configuration.Password))
            {
                localVarHeaderParams["Authorization"] = "Basic " + ApiClient.Base64Encode(this.Configuration.Username + ":" + this.Configuration.Password);
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("TranslateSynchronous", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<OutFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (OutFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(OutFile)));
        }

    }
}
