/* 
 * AT-RTS
 *
 * # AT-RTS (Remote Translation Service) API Documentation Welcome to the AT-RTS API documentation. AT-RTS is a robust web API designed to integrate our advanced translation systems into client systems, enabling full control over the content translation process. ## API Overview AT-RTS, built on a SOAP web service framework, offers REST interoperability starting from version 5.3.0, facilitating seamless integration into diverse environments. ### Key Functionalities   1. **Operating Check**      Verifies the active status of the service.   2. **Synchronous Translation**      Handles requests for immediate, automated (non-human) translation.   3. **Asynchronous Translation**      Processes orders for specialized professional translations on a deferred basis. Each request generates a unique token to identify and track the translation order. This token is essential for subsequent retrieval and proofreading of the translations.   ### Special Features   - **Callback URL**: Asynchronous translation requests can specify a callback URL to activate a notification service once the translation is complete. This allows clients to automate the download process of completed translations.   - **Translation Return Request**: Using the token from an asynchronous request, clients can retrieve the completed translation. If the translation is not yet complete, the system provides current status information.   - **Cancellation Request**: Allows clients to cancel previously submitted asynchronous translation requests using the token, provided the translation process has not yet commenced.   - **List of Requests**: Offers a comprehensive list detailing the status and usage of translation orders. Each entry includes:   - `projectid`: Unique identifier for the AT project.   - `token`: Token associated with the request.   - `sourcelang`: Source language of the text.   - `targetlang`: Target language for the translation.   - `filename`: File name associated with the request.   - `wordcount`: Total word count of the document.   - `status`: Current status of the translation (with codes such as 10: Under Review, 20: Ready, 30: Delivered, etc.).   - `urlcallback`: Optional URL for receiving completed translations.   - `errnotifiersendto`: Optional email address for receiving notifications on translation errors.   - `dateinsert`: Registration date of the translation request.   - `type`: Specifies whether the translation is SYNCHRONOUS or ASYNCHRONOUS.   ### Reliability Guarantees   ATLS Global ensures reliable return of asynchronous translations to client infrastructures. In the event of communication failures, the system is designed to alert clients through a warning email to the specified contact address, enhancing overall service reliability.   For detailed API usage examples and further technical information, refer to the subsequent sections of this documentation.
 *
 * OpenAPI spec version: 5.6.0
 * Contact: tec@at-ls.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using System.ComponentModel.DataAnnotations;
using SwaggerDateConverter = ATLS.Api.Client.SwaggerDateConverter;
namespace ATLS.Api.Model
{
    /// <summary>
    /// File information
    /// </summary>
    [DataContract]
        public partial class FileRTS :  IEquatable<FileRTS>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="FileRTS" /> class.
        /// </summary>
        /// <param name="token5">The token key is a string of alphanumeric characters generated by encryption from the ATLS Global SL system that acts as the unique identifier of the file associated with the asynchronous translation request..</param>
        /// <param name="token">The token key is a string of alphanumeric characters generated using UUID encryption that acts as the unique identifier of the file associated with the asynchronous translation request..</param>
        /// <param name="sourcelang">The sourcelang key is a source language code in ISO-639-3 format..</param>
        /// <param name="targetlang">The targetlang key is a target language code in ISO-639-3 format..</param>
        /// <param name="filename">The filename key indicates the name of the file..</param>
        /// <param name="wordcount">The wordcount key indicates the number of words in the file that have been translated..</param>
        /// <param name="idddv4">The idddv4 key indicates the internal identifier..</param>
        /// <param name="dateinsert">The dateinsert key indicates the insertion date of the file..</param>
        /// <param name="auxdata">The auxdata key indicates auxiliary values..</param>
        /// <param name="type">The type key indicates how the translation has been requested, synchronous or asynchronous..</param>
        /// <param name="projectid">The key projectid indicates the translation project identifier..</param>
        /// <param name="status">The status key indicates the status of the translation..</param>
        public FileRTS(string token5 = default(string), string token = default(string), string sourcelang = default(string), string targetlang = default(string), string filename = default(string), int? wordcount = default(int?), string idddv4 = default(string), DateTime? dateinsert = default(DateTime?), string auxdata = default(string), int? type = default(int?), int? projectid = default(int?), int? status = default(int?))
        {
            this.Token5 = token5;
            this.Token = token;
            this.Sourcelang = sourcelang;
            this.Targetlang = targetlang;
            this.Filename = filename;
            this.Wordcount = wordcount;
            this.Idddv4 = idddv4;
            this.Dateinsert = dateinsert;
            this.Auxdata = auxdata;
            this.Type = type;
            this.Projectid = projectid;
            this.Status = status;
        }
        
        /// <summary>
        /// The token key is a string of alphanumeric characters generated by encryption from the ATLS Global SL system that acts as the unique identifier of the file associated with the asynchronous translation request.
        /// </summary>
        /// <value>The token key is a string of alphanumeric characters generated by encryption from the ATLS Global SL system that acts as the unique identifier of the file associated with the asynchronous translation request.</value>
        [DataMember(Name="token_5", EmitDefaultValue=false)]
        public string Token5 { get; set; }

        /// <summary>
        /// The token key is a string of alphanumeric characters generated using UUID encryption that acts as the unique identifier of the file associated with the asynchronous translation request.
        /// </summary>
        /// <value>The token key is a string of alphanumeric characters generated using UUID encryption that acts as the unique identifier of the file associated with the asynchronous translation request.</value>
        [DataMember(Name="token", EmitDefaultValue=false)]
        public string Token { get; set; }

        /// <summary>
        /// The sourcelang key is a source language code in ISO-639-3 format.
        /// </summary>
        /// <value>The sourcelang key is a source language code in ISO-639-3 format.</value>
        [DataMember(Name="sourcelang", EmitDefaultValue=false)]
        public string Sourcelang { get; set; }

        /// <summary>
        /// The targetlang key is a target language code in ISO-639-3 format.
        /// </summary>
        /// <value>The targetlang key is a target language code in ISO-639-3 format.</value>
        [DataMember(Name="targetlang", EmitDefaultValue=false)]
        public string Targetlang { get; set; }

        /// <summary>
        /// The filename key indicates the name of the file.
        /// </summary>
        /// <value>The filename key indicates the name of the file.</value>
        [DataMember(Name="filename", EmitDefaultValue=false)]
        public string Filename { get; set; }

        /// <summary>
        /// The wordcount key indicates the number of words in the file that have been translated.
        /// </summary>
        /// <value>The wordcount key indicates the number of words in the file that have been translated.</value>
        [DataMember(Name="wordcount", EmitDefaultValue=false)]
        public int? Wordcount { get; set; }

        /// <summary>
        /// The idddv4 key indicates the internal identifier.
        /// </summary>
        /// <value>The idddv4 key indicates the internal identifier.</value>
        [DataMember(Name="idddv4", EmitDefaultValue=false)]
        public string Idddv4 { get; set; }

        /// <summary>
        /// The dateinsert key indicates the insertion date of the file.
        /// </summary>
        /// <value>The dateinsert key indicates the insertion date of the file.</value>
        [DataMember(Name="dateinsert", EmitDefaultValue=false)]
        public DateTime? Dateinsert { get; set; }

        /// <summary>
        /// The auxdata key indicates auxiliary values.
        /// </summary>
        /// <value>The auxdata key indicates auxiliary values.</value>
        [DataMember(Name="auxdata", EmitDefaultValue=false)]
        public string Auxdata { get; set; }

        /// <summary>
        /// The type key indicates how the translation has been requested, synchronous or asynchronous.
        /// </summary>
        /// <value>The type key indicates how the translation has been requested, synchronous or asynchronous.</value>
        [DataMember(Name="type", EmitDefaultValue=false)]
        public int? Type { get; set; }

        /// <summary>
        /// The key projectid indicates the translation project identifier.
        /// </summary>
        /// <value>The key projectid indicates the translation project identifier.</value>
        [DataMember(Name="projectid", EmitDefaultValue=false)]
        public int? Projectid { get; set; }

        /// <summary>
        /// The status key indicates the status of the translation.
        /// </summary>
        /// <value>The status key indicates the status of the translation.</value>
        [DataMember(Name="status", EmitDefaultValue=false)]
        public int? Status { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class FileRTS {\n");
            sb.Append("  Token5: ").Append(Token5).Append("\n");
            sb.Append("  Token: ").Append(Token).Append("\n");
            sb.Append("  Sourcelang: ").Append(Sourcelang).Append("\n");
            sb.Append("  Targetlang: ").Append(Targetlang).Append("\n");
            sb.Append("  Filename: ").Append(Filename).Append("\n");
            sb.Append("  Wordcount: ").Append(Wordcount).Append("\n");
            sb.Append("  Idddv4: ").Append(Idddv4).Append("\n");
            sb.Append("  Dateinsert: ").Append(Dateinsert).Append("\n");
            sb.Append("  Auxdata: ").Append(Auxdata).Append("\n");
            sb.Append("  Type: ").Append(Type).Append("\n");
            sb.Append("  Projectid: ").Append(Projectid).Append("\n");
            sb.Append("  Status: ").Append(Status).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as FileRTS);
        }

        /// <summary>
        /// Returns true if FileRTS instances are equal
        /// </summary>
        /// <param name="input">Instance of FileRTS to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(FileRTS input)
        {
            if (input == null)
                return false;

            return 
                (
                    this.Token5 == input.Token5 ||
                    (this.Token5 != null &&
                    this.Token5.Equals(input.Token5))
                ) && 
                (
                    this.Token == input.Token ||
                    (this.Token != null &&
                    this.Token.Equals(input.Token))
                ) && 
                (
                    this.Sourcelang == input.Sourcelang ||
                    (this.Sourcelang != null &&
                    this.Sourcelang.Equals(input.Sourcelang))
                ) && 
                (
                    this.Targetlang == input.Targetlang ||
                    (this.Targetlang != null &&
                    this.Targetlang.Equals(input.Targetlang))
                ) && 
                (
                    this.Filename == input.Filename ||
                    (this.Filename != null &&
                    this.Filename.Equals(input.Filename))
                ) && 
                (
                    this.Wordcount == input.Wordcount ||
                    (this.Wordcount != null &&
                    this.Wordcount.Equals(input.Wordcount))
                ) && 
                (
                    this.Idddv4 == input.Idddv4 ||
                    (this.Idddv4 != null &&
                    this.Idddv4.Equals(input.Idddv4))
                ) && 
                (
                    this.Dateinsert == input.Dateinsert ||
                    (this.Dateinsert != null &&
                    this.Dateinsert.Equals(input.Dateinsert))
                ) && 
                (
                    this.Auxdata == input.Auxdata ||
                    (this.Auxdata != null &&
                    this.Auxdata.Equals(input.Auxdata))
                ) && 
                (
                    this.Type == input.Type ||
                    (this.Type != null &&
                    this.Type.Equals(input.Type))
                ) && 
                (
                    this.Projectid == input.Projectid ||
                    (this.Projectid != null &&
                    this.Projectid.Equals(input.Projectid))
                ) && 
                (
                    this.Status == input.Status ||
                    (this.Status != null &&
                    this.Status.Equals(input.Status))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Token5 != null)
                    hashCode = hashCode * 59 + this.Token5.GetHashCode();
                if (this.Token != null)
                    hashCode = hashCode * 59 + this.Token.GetHashCode();
                if (this.Sourcelang != null)
                    hashCode = hashCode * 59 + this.Sourcelang.GetHashCode();
                if (this.Targetlang != null)
                    hashCode = hashCode * 59 + this.Targetlang.GetHashCode();
                if (this.Filename != null)
                    hashCode = hashCode * 59 + this.Filename.GetHashCode();
                if (this.Wordcount != null)
                    hashCode = hashCode * 59 + this.Wordcount.GetHashCode();
                if (this.Idddv4 != null)
                    hashCode = hashCode * 59 + this.Idddv4.GetHashCode();
                if (this.Dateinsert != null)
                    hashCode = hashCode * 59 + this.Dateinsert.GetHashCode();
                if (this.Auxdata != null)
                    hashCode = hashCode * 59 + this.Auxdata.GetHashCode();
                if (this.Type != null)
                    hashCode = hashCode * 59 + this.Type.GetHashCode();
                if (this.Projectid != null)
                    hashCode = hashCode * 59 + this.Projectid.GetHashCode();
                if (this.Status != null)
                    hashCode = hashCode * 59 + this.Status.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            yield break;
        }
    }
}
