/* 
 * AT-RTS
 *
 * # AT-RTS (Remote Translation Service) API Documentation Welcome to the AT-RTS API documentation. AT-RTS is a robust web API designed to integrate our advanced translation systems into client systems, enabling full control over the content translation process. ## API Overview AT-RTS, built on a SOAP web service framework, offers REST interoperability starting from version 5.3.0, facilitating seamless integration into diverse environments. ### Key Functionalities   1. **Operating Check**      Verifies the active status of the service.   2. **Synchronous Translation**      Handles requests for immediate, automated (non-human) translation.   3. **Asynchronous Translation**      Processes orders for specialized professional translations on a deferred basis. Each request generates a unique token to identify and track the translation order. This token is essential for subsequent retrieval and proofreading of the translations.   ### Special Features   - **Callback URL**: Asynchronous translation requests can specify a callback URL to activate a notification service once the translation is complete. This allows clients to automate the download process of completed translations.   - **Translation Return Request**: Using the token from an asynchronous request, clients can retrieve the completed translation. If the translation is not yet complete, the system provides current status information.   - **Cancellation Request**: Allows clients to cancel previously submitted asynchronous translation requests using the token, provided the translation process has not yet commenced.   - **List of Requests**: Offers a comprehensive list detailing the status and usage of translation orders. Each entry includes:   - `projectid`: Unique identifier for the AT project.   - `token`: Token associated with the request.   - `sourcelang`: Source language of the text.   - `targetlang`: Target language for the translation.   - `filename`: File name associated with the request.   - `wordcount`: Total word count of the document.   - `status`: Current status of the translation (with codes such as 10: Under Review, 20: Ready, 30: Delivered, etc.).   - `urlcallback`: Optional URL for receiving completed translations.   - `errnotifiersendto`: Optional email address for receiving notifications on translation errors.   - `dateinsert`: Registration date of the translation request.   - `type`: Specifies whether the translation is SYNCHRONOUS or ASYNCHRONOUS.   ### Reliability Guarantees   ATLS Global ensures reliable return of asynchronous translations to client infrastructures. In the event of communication failures, the system is designed to alert clients through a warning email to the specified contact address, enhancing overall service reliability.   For detailed API usage examples and further technical information, refer to the subsequent sections of this documentation.
 *
 * OpenAPI spec version: 5.6.0
 * Contact: tec@at-ls.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using System.ComponentModel.DataAnnotations;
using SwaggerDateConverter = ATLS.Api.Client.SwaggerDateConverter;
namespace ATLS.Api.Model
{
    /// <summary>
    /// File list return
    /// </summary>
    [DataContract]
        public partial class OutList :  IEquatable<OutList>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="OutList" /> class.
        /// </summary>
        /// <param name="error">error.</param>
        /// <param name="files">set of file information.</param>
        public OutList(ErrorResponse error = default(ErrorResponse), List<FileRTS> files = default(List<FileRTS>))
        {
            this.Error = error;
            this.Files = files;
        }
        
        /// <summary>
        /// Gets or Sets Error
        /// </summary>
        [DataMember(Name="error", EmitDefaultValue=false)]
        public ErrorResponse Error { get; set; }

        /// <summary>
        /// set of file information
        /// </summary>
        /// <value>set of file information</value>
        [DataMember(Name="files", EmitDefaultValue=false)]
        public List<FileRTS> Files { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class OutList {\n");
            sb.Append("  Error: ").Append(Error).Append("\n");
            sb.Append("  Files: ").Append(Files).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as OutList);
        }

        /// <summary>
        /// Returns true if OutList instances are equal
        /// </summary>
        /// <param name="input">Instance of OutList to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(OutList input)
        {
            if (input == null)
                return false;

            return 
                (
                    this.Error == input.Error ||
                    (this.Error != null &&
                    this.Error.Equals(input.Error))
                ) && 
                (
                    this.Files == input.Files ||
                    this.Files != null &&
                    input.Files != null &&
                    this.Files.SequenceEqual(input.Files)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Error != null)
                    hashCode = hashCode * 59 + this.Error.GetHashCode();
                if (this.Files != null)
                    hashCode = hashCode * 59 + this.Files.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            yield break;
        }
    }
}
